pub fn parse_source(src: &str) -> ImageSourceExpand description
Takes an image source string and determines the type of source it is, returning an ImageSource enum.
pub fn parse_source(src: &str) -> ImageSourceTakes an image source string and determines the type of source it is, returning an ImageSource enum.