pub struct HtmlRenderer { /* private fields */ }Implementations
Sourceimpl HtmlRenderer
impl HtmlRenderer
Sourcepub fn render(
&mut self,
html: &str,
available_width: f32,
debug: bool,
) -> Vec<DrawCommand>
pub fn render( &mut self, html: &str, available_width: f32, debug: bool, ) -> Vec<DrawCommand>
Renders the given HTML string into a list of draw commands to be used with GPUI to render HTML.
pub fn render_html( &mut self, html: &str, width: f32, debug: bool, ) -> Vec<DrawCommand>
Sourcepub fn style_tree(&mut self, html: &str) -> StyledNode
pub fn style_tree(&mut self, html: &str) -> StyledNode
Parses the given HTML into a tree and returns the root node of a style tree. Only used in test functions